@@ -25,13 +25,14 @@ enum AccessorType {
     PrivateClass,
     ObjectOnly,
     Constructor,
-    LazyClass
+    LazyClass,
+    InheritedCompat
 };
 
 /*
     - must have a value for each AccessorType element
     - '-2' will croak in av_extend() and is used as a guard
 */
-const int ALLOC_SIZE[] = {3, 3, 0, 0, -2, 1};
+const int ALLOC_SIZE[] = {3, 3, 0, 0, -2, 1, 3};
 
 #endif /* __INHERITED_XS_TYPES_H_ */
